USE [igops]
GO

DROP VIEW IF EXISTS role_policy_sod_v
GO

DROP VIEW IF EXISTS role_perm_policy_v
GO

CREATE VIEW role_policy_sod_v AS
  SELECT DISTINCT
    policy.id AS policy_id,
    policy.name,
    policy.deleted,
    policy.description,
    policy.detection_status,
    policy.risk,
    policy.state,
    policy.unique_policy_id,
    policy.cost,
    policy.risk_mode,
    sod.name AS sod_name,
    sod.description AS sod_desc,
    sod.deleted AS sod_deleted,
    sod.state AS sod_state
  FROM role_policy policy
    LEFT JOIN sod_condition_item sod_cond_item ON sod_cond_item.unique_id = policy.unique_policy_id
    LEFT JOIN sod_condition sod_cond ON sod_cond.id = sod_cond_item.condition
    LEFT JOIN sod_policy sod ON sod.id = sod_cond.policy;
GO

CREATE VIEW role_perm_policy_v AS
SELECT DISTINCT
  policy.id,
  policy.name AS policy_name,
  policy.unique_policy_id,
  policy.description AS policy_description,
  policy.created_by,
  policy.changed_by,
  policy.creation_time,
  policy.update_time,
  policy.deleted,
  policy.last_detection_time,
  CASE
    WHEN policy.state = 'INACTIVE' AND ISNULL(policy.detection_status,'INACTIVE') = 'INACTIVE' THEN 'Inactive'
    WHEN policy.state = 'ACTIVE' AND policy.detection_status IN ('COMPLETED','RUNNING') THEN 'Active'
    WHEN policy.state = 'INACTIVE' AND policy.detection_status = 'INVALID' THEN 'Invalid from inactive'
    WHEN policy.state = 'INVALID' AND policy.detection_status = 'INVALID' THEN 'Invalid from active'
    ELSE NULL
  END AS current_state,
  policy.state AS actual_state,
  policy.detection_status,
  policy.risk_mode AS policy_risk_mode,
  policy.risk AS policy_risk,
  policy.cost AS policy_cost,
  (SELECT STUFF((SELECT ' | ' + powner.unique_owner_id
    FROM policy_owners_v powner
    LEFT JOIN role_policy rperm ON rperm.id = powner.role_policy
    WHERE powner.is_user = 1 AND rperm.id = policy.id
    GROUP BY powner.unique_owner_id
    FOR XML PATH('')), 1, 3, '') AS user_owner_id) AS user_owner_id,
  (SELECT STUFF((SELECT ' | ' + powner.unique_owner_id
    FROM policy_owners_v powner
    LEFT JOIN role_policy rperm ON rperm.id = powner.role_policy
    WHERE powner.is_user = 0 AND rperm.id = policy.id
    GROUP BY powner.unique_owner_id
    FOR XML PATH('')), 1, 3, '') AS group_owner_id) AS group_owner_id,
  (SELECT STUFF((SELECT ' | ' + powner.owner_name
    FROM policy_owners_v powner
    LEFT JOIN role_policy rperm ON rperm.id = powner.role_policy
    WHERE powner.is_user = 1 AND rperm.id = policy.id
    GROUP BY powner.owner_name
    FOR XML PATH('')), 1, 3, '') AS user_owner_id) AS user_owners,
  (SELECT STUFF((SELECT ' | ' + powner.owner_name
    FROM policy_owners_v powner
    LEFT JOIN role_policy rperm ON rperm.id = powner.role_policy
    WHERE powner.is_user = 0 AND rperm.id = policy.id
    GROUP BY powner.owner_name
    FOR XML PATH('')), 1, 3, '') AS user_owner_id) AS group_owners,
  perm.unique_permission_id,
  perm.name AS perm_name,
  perm_user.unique_user_id AS permission_user_id,
  perm_user.display_name AS permission_user_name
FROM
  role_policy policy
  LEFT JOIN policy_owner ON policy.id = policy_owner.role_policy
  LEFT JOIN role_permission role_perm ON  policy.id = role_perm.policy
  LEFT JOIN spermission perm ON role_perm.unique_permission_id = perm.unique_permission_id AND perm.effective = 1
  LEFT JOIN suser_account_permission_role role_user ON  role_user.role = policy.id
  LEFT JOIN suser perm_user ON  perm_user.id = role_user.suser
GO

GRANT SELECT ON role_policy_sod_v TO ig_report_role
GO

GRANT SELECT ON role_perm_policy_v TO ig_report_role
GO
